@@ -26,7 +26,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = '4.1';
+our $VERSION = '4.2';
 
 # Preloaded methods go here.
 sub ngroup {
@@ -156,7 +156,9 @@ reformed can be passed as a reference.
 
 =head1 AUTHOR
 
-Terrence Monroe Brannon <tbone@CPAN.org>
+Currently maintained by Mike Accardo, <accardo@cpan.org>
+
+Original author Terrence Monroe Brannon.
 
 =head2 CONTRIBUTORS
 
@@ -167,7 +169,8 @@ He also upgraded the Makefile.PL.
 
 =head1 COPYRIGHT
 
-Copyright 1999-present by Terrence Brannon.
+    Copyright (c) 2015 Mike Accardo
+    Copyright (c) 1999-2014 Terrence Brannon 
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
